---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_deployment Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a Deployment resource.
  A Deployment is the result of building your Project and making it available through a live URL.
  When making deployments, the Project will be uploaded and transformed into a production-ready output through the use of a Build Step.
  Once the build step has completed successfully, a new, immutable deployment will be made available at the preview URL. Deployments are retained indefinitely unless deleted manually.
  -> In order to provide files to a deployment, you'll need to use the vercel_file or vercel_project_directory data sources.
  ~> If you are creating Deployments through terraform and intend to use both preview and production
  deployments, you may wish to 'layer' your terraform, creating the Project with a different set of
  terraform to your Deployment.
---

# vercel_deployment (Resource)

Provides a Deployment resource.

A Deployment is the result of building your Project and making it available through a live URL.

When making deployments, the Project will be uploaded and transformed into a production-ready output through the use of a Build Step.

Once the build step has completed successfully, a new, immutable deployment will be made available at the preview URL. Deployments are retained indefinitely unless deleted manually.

-> In order to provide files to a deployment, you'll need to use the `vercel_file` or `vercel_project_directory` data sources.

~> If you are creating Deployments through terraform and intend to use both preview and production
deployments, you may wish to 'layer' your terraform, creating the Project with a different set of
terraform to your Deployment.

## Example Usage

```terraform
# In this example, we are assuming that a nextjs UI
# exists in a `ui` directory and any terraform exists in a `terraform` directory.
# E.g.
# ```
# ui/
#    src/
#        index.js
#    package.json
#    // etc...
# terraform/
#    main.tf
# ```

data "vercel_project_directory" "files_example" {
  path = "../ui"
}

data "vercel_project" "files_example" {
  name = "my-awesome-project"
}

resource "vercel_deployment" "files_example" {
  project_id  = data.vercel_project.files_example.id
  files       = data.vercel_project_directory.files_example.files
  path_prefix = data.vercel_project_directory.files_example.path
  production  = true

  environment = {
    FOO = "bar"
  }
}

## Or deploying a specific commit or branch
resource "vercel_project" "git_example" {
  name      = "my-awesome-git-project"
  framework = "nextjs"
  git_repository = {
    type = "github"
    repo = "vercel/some-repo"
  }
}

resource "vercel_deployment" "git_example" {
  project_id = vercel_project.git_example.id
  ref        = "d92f10e" # or a git branch
}

## Or deploying a prebuilt project 
data "vercel_project" "prebuilt_example" {
  name = "my-prebuilt-project"
}

data "vercel_prebuilt_project" "prebuilt_example" {
  path = "../ui"
}

resource "vercel_deployment" "prebuilt_example" {
  project_id  = data.vercel_project.prebuilt_example.id
  files       = data.vercel_prebuilt_project.prebuilt_example.output
  path_prefix = data.vercel_prebuilt_project.prebuilt_example.path
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `project_id` (String) The project ID to add the deployment to.

### Optional

- `delete_on_destroy` (Boolean) Set to true to hard delete the Vercel deployment when destroying the Terraform resource. If unspecified, deployments are retained indefinitely. Note that deleted deployments are not recoverable.
- `environment` (Map of String) A map of environment variable names to values. These are specific to a Deployment, and can also be configured on the `vercel_project` resource.
- `files` (Map of String) A map of files to be uploaded for the deployment. This should be provided by a `vercel_project_directory` or `vercel_file` data source. Required if `git_source` is not set.
- `path_prefix` (String) If specified then the `path_prefix` will be stripped from the start of file paths as they are uploaded to Vercel. If this is omitted, then any leading `../`s will be stripped.
- `production` (Boolean) true if the deployment is a production deployment, meaning production aliases will be assigned.
- `project_settings` (Attributes) Project settings that will be applied to the deployment. (see [below for nested schema](#nestedatt--project_settings))
- `ref` (String) The branch or commit hash that should be deployed. Note this will only work if the project is configured to use a Git repository. Required if `ref` is not set.
- `team_id` (String) The team ID to add the deployment to.

### Read-Only

- `domains` (List of String) A list of all the domains (default domains, staging domains and production domains) that were assigned upon deployment creation.
- `id` (String) The ID of this resource.
- `url` (String) A unique URL that is automatically generated for a deployment.

<a id="nestedatt--project_settings"></a>
### Nested Schema for `project_settings`

Optional:

- `build_command` (String) The build command for this deployment. If omitted, this value will be taken from the project or automatically detected.
- `framework` (String) The framework that is being used for this deployment. If omitted, no framework is selected.
- `install_command` (String) The install command for this deployment. If omitted, this value will be taken from the project or automatically detected.
- `output_directory` (String) The output directory of the deployment. If omitted, this value will be taken from the project or automatically detected.
- `root_directory` (String) The name of a directory or relative path to the source code of your project. When null is used it will default to the project root.


